==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/inputs/FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.inputs

import com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property object Object specified in the flow destination.
 */
public data class FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs(
    public val `object`: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs> {
    override fun toJava():
        com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs =
        com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs.builder()
            .`object`(`object`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs].
 */
@PulumiTagMarker
public class FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgsBuilder internal
constructor() {
    private var `object`: Output<String>? = null

    /**
     * @param value Object specified in the flow destination.
     */
    @JvmName("uokmxedyevfaoeks")
    public suspend fun `object`(`value`: Output<String>) {
        this.`object` = value
    }

    /**
     * @param value Object specified in the flow destination.
     */
    @JvmName("hpfdjslusmknvmkc")
    public suspend fun `object`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`object` = mapped
    }

    internal fun build(): FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs =
        FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs(
            `object` = `object` ?: throw PulumiNullFieldException("object"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/inputs/FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.inputs

import com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property object
 */
public data class FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs(
    public val `object`: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs> {
    override fun toJava(): com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs =
        com.pulumi.aws.appflow.inputs.FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs.builder()
            .`object`(`object`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs].
 */
@PulumiTagMarker
public class FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgsBuilder internal constructor() {
    private var `object`: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("eaiyoianqiinlmla")
    public suspend fun `object`(`value`: Output<String>) {
        this.`object` = value
    }

    /**
     * @param value
     */
    @JvmName("wgqeyveilywtkwcq")
    public suspend fun `object`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`object` = mapped
    }

    internal fun build(): FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs =
        FlowSourceFlowConfigSourceConnectorPropertiesInforNexusArgs(
            `object` = `object` ?: throw PulumiNullFieldException("object"),
        )
}
